@@ -27,8 +27,8 @@ import sipconfig
 # These are installation specific values created when PyQt was configured.
 _pkg_config = {
     'pyqt_bin_dir':              '/usr/local/bin',
-    'pyqt_config_args':          '-w -b /usr/local/bin -d /usr/local/lib/python2.5/site-packages -g /usr/local/include/X11/qt3 -l /usr/local/include/python2.5 -m /usr/local/lib/qt3 -q /usr/local/lib/qt3 -v /usr/local/share/sip -y qt-mt INCDIR_QT=/usr/local/include/X11/qt3 LIBDIR=/usr/local/lib LIBDIR_QT=/usr/local/lib/qt3 CC=cc CXX=c++ CFLAGS=-O2 -pipe  CXXFLAGS=-O2 -pipe ',
-    'pyqt_mod_dir':              '/usr/local/lib/python2.5/site-packages',
+    'pyqt_config_args':          '-w -b /usr/local/bin -d /usr/local/lib/python2.6/site-packages -g /usr/local/include/X11/qt3 -l /usr/local/include/python2.6 -m /usr/local/lib/qt3 -q /usr/local/lib/qt3 -v /usr/local/share/sip -y qt-mt INCDIR_QT=/usr/local/include/X11/qt3 LIBDIR=/usr/local/lib LIBDIR_QT=/usr/local/lib/qt3 CC=cc CXX=c++ CFLAGS=-O2 -pipe  CXXFLAGS=-O2 -pipe ',
+    'pyqt_mod_dir':              '/usr/local/lib/python2.6/site-packages',
     'pyqt_modules':              'qt qtcanvas qtnetwork qttable qtxml qtgl qtui qtsql',
     'pyqt_qt_sip_flags':         '-x Qt_STYLE_WINDOWSXP -x Qt_STYLE_INTERLACE -x Qt_STYLE_WINDOWSXP -x Qt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t Qt_3_3_6',
     'pyqt_qtcanvas_sip_flags':   '-x Qt_STYLE_WINDOWSXP -x Qt_STYLE_INTERLACE -x Qt_STYLE_WINDOWSXP -x Qt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t Qt_3_3_6',
@@ -39,8 +39,8 @@ _pkg_config = {
     'pyqt_qtui_sip_flags':       '-x Qt_STYLE_WINDOWSXP -x Qt_STYLE_INTERLACE -x Qt_STYLE_WINDOWSXP -x Qt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t Qt_3_3_6',
     'pyqt_qtxml_sip_flags':      '-x Qt_STYLE_WINDOWSXP -x Qt_STYLE_INTERLACE -x Qt_STYLE_WINDOWSXP -x Qt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t Qt_3_3_6',
     'pyqt_sip_dir':              '/usr/local/share/sip',
-    'pyqt_version':              0x031106,
-    'pyqt_version_str':          '3.17.6',
+    'pyqt_version':              0x031201,
+    'pyqt_version_str':          '3.18.1',
     'qt_dir':                    '/usr/local/lib/qt3',
     'qt_edition':                'free',
     'qt_framework':              0,
@@ -112,6 +112,7 @@ _default_macros = {
     'LFLAGS_OPENGL':            '',
     'LFLAGS_PLUGIN':            '-shared',
     'LFLAGS_RELEASE':           '',
+    'LFLAGS_RPATH':             '',
     'LFLAGS_SHLIB':             '-shared',
     'LFLAGS_SONAME':            '',
     'LFLAGS_THREAD':            '-pthread',
@@ -131,6 +132,7 @@ _default_macros = {
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
     'LIBS_THREAD':              '',
+    'LIBS_WEBKIT':              '',
     'LIBS_WINDOWS':             '',
     'LIBS_X11':                 '-lXext -lX11 -lm',
     'LINK':                     'g++',
